#!/usr/bin/env python3
# -*- coding: utf-8 -*-

#
# Copyright (c) 2024 Lanzhou University
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from liscopelens.parser.inspector import QueryParser
from liscopelens.parser.base import BaseParserEntry


class QueryEntry(BaseParserEntry):
    parsers = (QueryParser,)

    entry_name: str = "inspect"
    entry_help: str = "This parser is used to inspect the results of the others parser"
